package
module
Version:
v0.0.1
Opens a new window with list of versions in this module.
Published: Feb 17, 2020
License: BSD-3-Clause
Opens a new window with license information.
Imports: 8
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Options struct {
Reconnect bool
}
type Payload struct {
Event string `json:"event,omitempty"`
Data interface{} `json:"data,omitempty"`
Ack string `json:"ack,omitempty"`
}
Source Files
¶
Directories
¶
Click to show internal directories.
Click to hide internal directories.